==> jx-common-log-1.0.0-20180720.092126-1-sources.jar: com/junxin/common/log/entity/SystemLogEntity.java <==

/*
 * Copyright (C), 2013-2018, 北京君信微科科技有限公司
 * FileName: SystemLog.java
 * Author:   ailikes
 * Date:     2018年7月20日 上午10:58:15
 * Description: //模块目的、功能描述      
 * History: //修改记录
 * <author>      <time>      <version>    <desc>
 * 修改人姓名             修改时间            版本号                  描述
 */
package com.junxin.common.log.entity;

import java.io.Serializable;

/** 
 * 功能描述: 日志记录实体
 * 
 * @version 1.0.0
 * @since 1.0.0 
 * @author ailikes
 * Date:   2018年7月20日 上午10:58:15
 */

public class SystemLogEntity implements Serializable{
    
    private static final long serialVersionUID = 252096510922787652L;
    /**
     * 用户ID
     */
    private String userId;
    /**
     * 用户类型
     */
    private String userType;
    /**
     * 用户名
     */
    private String userName;
    /**
     * 用户组织结构
     */
    private String userOrg;
    /**
     * 模块
     */
    private String module;
    /**
     * 方法
     */
    private String method;
    /**
     * 响应时间
     */
    private String responseTime;
    /**
     * 操作IP
     */
    private String ip;
    /**
     * 时间
     */
    private String date;
    /**
     * 描述
     */
    private String commit;

    public String getUserId() {
    
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getUserName() {
    
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getModule() {
    
        return module;
    }

    public void setModule(String module) {
        this.module = module;
    }

    public String getMethod() {
    
        return method;
    }

    public void setMethod(String method) {
        this.method = method;
    }

    public String getResponseTime() {
    
        return responseTime;
    }

    public void setResponseTime(String responseTime) {
        this.responseTime = responseTime;
    }

    public String getIp() {
    
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public String getDate() {
    
        return date;
    }

    public void setDate(String date) {
        this.date = date;
    }

    public String getCommit() {
    
        return commit;
    }

    public void setCommit(String commit) {
        this.commit = commit;
    }

    public String getUserType() {
    
        return userType;
    }

    public void setUserType(String userType) {
        this.userType = userType;
    }

    public String getUserOrg() {
    
        return userOrg;
    }

    public void setUserOrg(String userOrg) {
        this.userOrg = userOrg;
    }

    @Override
    public String toString() {
        return "SystemLogEntity [userId=" + userId + ", userType=" + userType + ", userName=" + userName + ", userOrg=" + userOrg + ", module=" + module + ", method=" + method + ", responseTime=" + responseTime + ", ip=" + ip + ", date=" + date + ", commit=" + commit + "]";
    }
    
}

==> jx-common-log-1.0.0-20180721.041003-6-sources.jar: com/junxin/common/log/entity/SystemLogEntity.java <==

/*
 * Copyright (C), 2013-2018, 北京君信微科科技有限公司
 * FileName: SystemLog.java
 * Author:   ailikes
 * Date:     2018年7月20日 上午10:58:15
 * Description: //模块目的、功能描述      
 * History: //修改记录
 * <author>      <time>      <version>    <desc>
 * 修改人姓名             修改时间            版本号                  描述
 */
package com.junxin.common.log.entity;

import java.io.Serializable;

/** 
 * 功能描述: 日志记录实体
 * 
 * @version 1.0.0
 * @since 1.0.0 
 * @author ailikes
 * Date:   2018年7月20日 上午10:58:15
 */

public class SystemLogEntity implements Serializable{
    
    private static final long serialVersionUID = 252096510922787652L;
    
    private String id;
    /**
     * 用户ID
     */
    private String userId;
    /**
     * 用户类型
     */
    private String userType;
    /**
     * 用户名
     */
    private String userName;
    /**
     * 用户组织结构
     */
    private String userOrg;
    /**
     * 模块
     */
    private String module;
    /**
     * 方法
     */
    private String method;
    /**
     * 响应时间
     */
    private String responseTime;
    /**
     * 操作IP
     */
    private String ip;
    /**
     * 时间
     */
    private String createTime;
    /**
     * 描述
     */
    private String commit;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getUserId() {
    
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getUserName() {
    
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getModule() {
    
        return module;
    }

    public void setModule(String module) {
        this.module = module;
    }

    public String getMethod() {
    
        return method;
    }

    public void setMethod(String method) {
        this.method = method;
    }

    public String getResponseTime() {
    
        return responseTime;
    }

    public void setResponseTime(String responseTime) {
        this.responseTime = responseTime;
    }

    public String getIp() {
    
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public String getCreateTime() {
    
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getCommit() {
    
        return commit;
    }

    public void setCommit(String commit) {
        this.commit = commit;
    }

    public String getUserType() {
    
        return userType;
    }

    public void setUserType(String userType) {
        this.userType = userType;
    }

    public String getUserOrg() {
    
        return userOrg;
    }

    public void setUserOrg(String userOrg) {
        this.userOrg = userOrg;
    }

    @Override
    public String toString() {
        return "SystemLogEntity [userId=" + userId + ", userType=" + userType + ", userName=" + userName + ", userOrg=" + userOrg + ", module=" + module + ", method=" + method + ", responseTime=" + responseTime + ", ip=" + ip + ", createTime=" + createTime + ", commit=" + commit + "]";
    }
    
}
